# FreeGenius AI

FreeGenius AI is an ambitious project sparked by the pioneering work of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). It's designed with the primary objective of offering a comprehensive suite of AI solutions that mirror the capabilities of [LetMeDoIt AI](https://github.com/eliranwong/letmedoit). However, FreeGenius AI is remarkably different in that all core features are completely free, and it doesn't require the use of an OpenAI key.

As with [LetMeDoIt AI](https://github.com/eliranwong/letmedoit), FreeGenius AI is designed to be capable of engaging in intuitive conversations, executing codes, providing up-to-date information, and performing a wide range of tasks. It's designed to learn, adapt, and grow with the user, offering personalized experiences and interactions.

Our recent developments, for example, [the ability to run multiple tools in a single request](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Running%20Multiple%20Tools%20in%20One%20Go.md), demonstrate that FreeGenius AI is far more capable than LetMeDoIt AI, while we still maintain backward compatibility with [LetMeDoIt AI](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/LetMeDoIt%20Mode.md).

# Latest changes

https://github.com/eliranwong/freegenius/blob/main/latest_changes.md

## Beyond LetMeDoIt AI

https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/LetMeDoIt%20Mode.md

# Distinctive Features

[Support Wide Range of Backends and Models](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Supported%20Backends%20and%20Models.md)

[Tool Calling for Any LLMs](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Function%20Call%20Approach%20with%20Any%20LLMs.md)

[Running Multiple Tools in One Go](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Running%20Multiple%20Tools%20in%20One%20Go.md)

[Highly Customisable Plugins](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/000_Home.md#plugins)

[Integration with Popular AI Tools](https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/000_Home.md#integration)

# Quick Tool Calling

Version 0.2.86+ supports use of `@` to specify a tool.  Available tools:

@chat @paste_from_clipboard @improve_writing @convert_relative_datetime @copy_to_clipboard @append_prompt @command @append_command @fabric @append_fabric @list_current_directory_contents @extract_python_code @run_python_code @integrate_google_searches @add_google_calendar_event @add_outlook_calendar_event @analyze_audio @analyze_files @analyze_images @analyze_web_content @ask_chatgpt @ask_codey @ask_gemini @ask_groq @ask_llama3_1 @ask_llamacpp @ask_llamacppserver @ask_ollama @ask_palm2 @correct_python @build_agents @create_image @create_map @create_qrcode @create_statistical_graphics @datetimes @download_web_content @download_youtube_audio @download_youtube_video @edit_text @execute_computing_task @install_package @save_memory @retrieve_memory @modify_images @open_browser @pronunce_words @remove_image_background @search_chats @load_chats @search_finance @search_latest_news @search_sqlite @search_weather_info @send_gamil @send_outlook @send_tweet

![tools](https://github.com/user-attachments/assets/d3a301ee-a228-4d0c-882e-0dd06141be2f)

Remarks: 

* `@chat` is regarded as a single tool.  If you just want a direct response generated by LLM, simply use `@chat`.
* `@execute_computing_task` is like a magic tool designed to execute computing tasks on demand.

Tips: Enter `@` to get input suggestions of available tools

# Selective Features

# Multiple Tools in One Go

From version 0.2.87+, FreeGenius AI supports use of multiple tools in a single request. It enables individual tools to work on results, generated by running previous tools.

![multiple_tools_in_single_prompt](https://github.com/user-attachments/assets/7bdc63cd-beca-44c9-bfb0-27596a5e0632)

Read more at: https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Running%20Multiple%20Tools%20in%20One%20Go.md

# Customizable Plugins

![plugins](https://github.com/eliranwong/freegenius/assets/25262722/6bb4b2f6-5684-42c1-95e3-7b12c3a38db6)

# System Command and Fabric Integration

System Command Integration: https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/System%20Command%20Integration.md

Fabric Integration: https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Fabric%20Integration.md

# Support GPU Offloading

![llamacpp_with_gpu_offloading_compressed](https://github.com/eliranwong/freegenius/assets/25262722/2d607fc1-e6b5-4c62-be14-325d73866fce)

# Access to Real-time Data

![realtime_information](https://github.com/eliranwong/freegenius/assets/25262722/d94fd9c3-f242-4c8c-8564-308f866e9adb)

# Access to Device Information

![access_device_information](https://github.com/eliranwong/freegenius/assets/25262722/6e3386a4-7314-4ce5-a64f-fffe35dff92e)

# Task Execution

![freegenius_ai_screenshot](https://github.com/eliranwong/freegenius/assets/25262722/1e9dd18e-aa4b-4e2c-8d76-386af7ba00ea)

# Content Creation

![content_creation](https://github.com/eliranwong/freegenius/assets/25262722/5582d519-b925-4e1b-8fd8-ecaa8422d391)

# Supported Platforms

Windows, macOS, Linux

Upcoming: Android

# Installation - an example

Install FreeGenius AI, by running:

To set up virtual environment (recommended):

> mkdir -p ~/apps/freegenius

> cd ~/apps/freegenius

> python3 -m venv freegenius

> source freegenius/bin/activate

To install:

> pip install --upgrade freegenius

Remarks: Auto-upgrade is supported in macOS and Linux versions, but not in Windows version.  Windows users need to manually upgrade to get the latest features.

To run:

> freegenius

To start up with a particular backend, you may use parameter `-b`, e.g.:

> freegenius -b groq

Read more at https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/000_Home.md#installation

# Quick Guide

https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/Quick%20Guide.md

# More

Documentation https://github.com/eliranwong/freegenius/blob/main/package/freegenius/docs/000_Home.md

# Welcome Contributions

You are welcome to make contributions to this project by:

* joining the development collaboratively

* donations to show support and invest for the future

Support link: https://www.paypal.me/letmedoitai

Please kindly report of any issues at https://github.com/eliranwong/freegenius/issues
